@@ -21,13 +21,13 @@ import math
 
 class DiscreteEnv(gym.Env):
   def __init__(self):
-    self.size = 20
+    self.size = 200
     #get initial values for theta's
     #fit logit model to data
     self.df = pd.DataFrame(dict(
             Xs=truncnorm.rvs(a=0, b= math.inf,size=self.size),
             Xa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
-            Y=np.random.binomial(1, 0.5, self.size)))
+            Y=np.random.binomial(1, 0.005, self.size)))
     self.model = LogisticRegression().fit(self.df[["Xs", "Xa"]], np.ravel(self.df[["Y"]].astype(int)))
 
     #extract theta parameters from the fitted logistic
@@ -48,11 +48,11 @@ class DiscreteEnv(gym.Env):
     
     
     #set ACTION SPACE
-    self.row = np.linspace(-2, 2, 50).tolist()
+    self.row = np.linspace(-2, 2, 10).tolist()
     self.action_space = spaces.Tuple((
-      spaces.Discrete(50),
-      spaces.Discrete(50),
-      spaces.Discrete(50)))
+      spaces.Discrete(10),
+      spaces.Discrete(10),
+      spaces.Discrete(10)))
    
     
     #set ACTION SPACE
@@ -88,7 +88,7 @@ class DiscreteEnv(gym.Env):
     
     #recover action value using indexes from onerow
     action0, action1, action2 = action[0], action[1], action[2]
-    action_0, action_1, action_2 = self.onerow[action0], self.onerow[action1], self.onerow[action2]   
+    action_0, action_1, action_2 = self.row[action0], self.row[action1], self.row[action2]   
 
       
     data = []
